/**
    @file ft51_security_registers.h

    @brief Security registers library

    Definitions for security settings of MTP memory.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_SECURITY_REGISTERS_H__
#define __FT51_SECURITY_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 57 (0x39) TOP_SECURITY_LEVEL
#define TOP_SECURITY_LEVEL                    0x39

// Register 57 Bit Definitions
#define BIT_SECTOR_1                          0                                 // Reflects the security level stored in MTP, after a reset
#define MASK_SECTOR_1                         (0x1 << BIT_SECTOR_1)
#define BIT_SECTOR_2                          1                                 // Reflects the security level stored in MTP, after a reset
#define MASK_SECTOR_2                         (0x1 << BIT_SECTOR_2)
#define BIT_SECTOR_3                          2                                 // Reflects the security level stored in MTP, after a reset
#define MASK_SECTOR_3                         (0x1 << BIT_SECTOR_3)
#define BIT_SECTOR_4                          3                                 // Reflects the security level stored in MTP, after a reset
#define MASK_SECTOR_4                         (0x1 << BIT_SECTOR_4)
#define BIT_GLOBAL_BIT                        4                                 // Reflects the security level stored in MTP, after a reset
#define MASK_GLOBAL_BIT                       (0x1 << BIT_GLOBAL_BIT)
#define MASK_SECURITY_LEVEL                   (0x1F << BIT_SECTOR_1)

#endif // __FT51_SECURITY_REGISTERS_H__
